@@ -3,4 +3,4 @@
 # This file is hereby placed in the public domain.
 
 [ -z "$DEPENDFILE" ] && DEPENDFILE=.depend
-${CC-cc} $CPPFLAGS -MM $* > $DEPENDFILE
+${CC-cc} $CPPFLAGS -MM "$@" > "$DEPENDFILE"
